@@ -1,7 +1,6 @@
 import requests
 import websocket
 import json
-import threading
 import concurrent.futures
 from io import BytesIO
 from typing import Dict
@@ -9,6 +8,7 @@ from typing import Dict
 from .utils import *
 from .message import *
 from .schedule import Scheduler
+from .threadpool import ThreadPool
 
 
 class Mirai(metaclass=Singleton):
@@ -34,17 +34,24 @@ class Mirai(metaclass=Singleton):
         self.base_url: str = f'{adapter}://localhost:{port}'
         self.session_key: Optional[str] = session_key
         self.adapter: str = adapter
+        self.thread_pool: ThreadPool = ThreadPool()
 
         self.__session: Optional[Union[requests.session, websocket.WebSocket]] = None
         self.__msg_pool: Dict[str, json] = {}
         self.__scheduler: Scheduler = Scheduler()
 
-    def get_version(self):
+    def version(self):
         """获取 mirai-api-http 的版本号"""
         response = requests.get(url=f'{self.base_url}/about').json()
         if 'data' in response and 'version' in response['data']:
             return response['data']['version']
 
+    def get_version(self):
+        warnings.warn('get_version 方法已弃用，请使用 version 代替', DeprecationWarning)
+        response = requests.get(url=f'{self.base_url}/about').json()
+        if 'data' in response and 'version' in response['data']:
+            return response['data']['version']
+
     def run(self):
         """开始运行"""
         if self.adapter == 'http':
@@ -157,8 +164,7 @@ class Mirai(metaclass=Singleton):
                     print(msg)
                     funcs = self.receiver_funcs.get(msg_type, [])
                     if funcs:
-                        msg_thread = threading.Thread(target=self.__call_plugins, args=(funcs, msg))
-                        msg_thread.start()
+                        self.thread_pool.add_task(target=self.__call_plugins, args=(funcs, msg))
             except:
                 continue
 
@@ -172,8 +178,7 @@ class Mirai(metaclass=Singleton):
     @start_log
     def __ws_main_loop(self):
         """ws 主循环"""
-        schedule_thread = threading.Thread(target=self.__call_schedule_plugins)
-        schedule_thread.start()
+        self.thread_pool.add_task(target=self.__call_schedule_plugins)
         while True:
             try:
                 msg_json = json.loads(self.__session.recv())
@@ -184,8 +189,7 @@ class Mirai(metaclass=Singleton):
                     print(msg)
                     funcs = self.receiver_funcs.get(msg_type, [])
                     if funcs:
-                        msg_thread = threading.Thread(target=self.__call_plugins, args=(funcs, msg))
-                        msg_thread.start()
+                        self.thread_pool.add_task(target=self.__call_plugins, args=(funcs, msg))
                 else:
                     response = msg_json['data']
                     sync_id = msg_json['syncId']
@@ -323,7 +327,21 @@ class Mirai(metaclass=Singleton):
             msg_chain.append(msg.to_json())
         return msg_chain
 
-    def get_friend_list(self):
+    def recall(self, msg_id: int):
+        """撤回消息
+        :param msg_id: 需要撤回的消息的 messageId
+        :return: mirai-api-http 的响应
+        """
+        content = {'sessionKey': self.session_key,
+                   'target': msg_id}
+        if self.adapter == 'http':
+            response = self.__session.post(url=f'{self.base_url}/recall', json=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='recall', content=content)
+            return response
+
+    def friend_list(self):
         """获取好友列表"""
         content = {'sessionKey': self.session_key}
         if self.adapter == 'http':
@@ -333,21 +351,17 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send(command='friendList', content=content)
             return response
 
-    def recall(self, id: int):
-        """撤回消息
-        :param id: 需要撤回的消息的 messageId
-        :return: mirai-api-http 的响应
-        """
-        content = {'sessionKey': self.session_key,
-                   'target': id}
+    def get_friend_list(self):
+        warnings.warn('get_friend_list 方法已弃用，请使用 friend_list 代替', DeprecationWarning)
+        content = {'sessionKey': self.session_key}
         if self.adapter == 'http':
-            response = self.__session.post(url=f'{self.base_url}/recall', json=content).json()
+            response = self.__session.get(url=f'{self.base_url}/friendList', params=content).json()
             return response
         elif self.adapter == 'ws':
-            response = self.__ws_send(command='recall', content=content)
+            response = self.__ws_send(command='friendList', content=content)
             return response
 
-    def get_group_list(self):
+    def group_list(self):
         """获取群列表"""
         content = {'sessionKey': self.session_key}
         if self.adapter == 'http':
@@ -357,7 +371,17 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send(command='groupList', content=content)
             return response
 
-    def get_member_list(self, group: int):
+    def get_group_list(self):
+        warnings.warn('get_group_list 方法已弃用，请使用 group_list 代替', DeprecationWarning)
+        content = {'sessionKey': self.session_key}
+        if self.adapter == 'http':
+            response = self.__session.get(url=f'{self.base_url}/groupList', params=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='groupList', content=content)
+            return response
+
+    def member_list(self, group: int):
         """获取群成员列表"""
         content = {'sessionKey': self.session_key,
                    'target': group}
@@ -368,16 +392,15 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send(command='memberList', content=content)
             return response
 
-    def session_info(self):
-        """获取 session 信息
-        :return session 信息
-        """
-        content = {'sessionKey': self.session_key}
+    def get_member_list(self, group: int):
+        warnings.warn('get_member_list 方法已弃用，请使用 member_list 代替', DeprecationWarning)
+        content = {'sessionKey': self.session_key,
+                   'target': group}
         if self.adapter == 'http':
-            response = self.__session.get(url=f'{self.base_url}/sessionInfo', params=content).json()
+            response = self.__session.get(url=f'{self.base_url}/memberList', params=content).json()
             return response
         elif self.adapter == 'ws':
-            response = self.__ws_send(command='sessionInfo', content=content)
+            response = self.__ws_send(command='memberList', content=content)
             return response
 
     def bot_profile(self):
@@ -422,6 +445,18 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send(command='memberProfile', content=content)
             return response
 
+    def session_info(self):
+        """获取 session 信息
+        :return session 信息
+        """
+        content = {'sessionKey': self.session_key}
+        if self.adapter == 'http':
+            response = self.__session.get(url=f'{self.base_url}/sessionInfo', params=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='sessionInfo', content=content)
+            return response
+
     def upload_img(self, img: Image, type='group'):
         """图片文件上传，当前仅支持 http
         :param img: 上传的 Image 对象
@@ -461,6 +496,19 @@ class Mirai(metaclass=Singleton):
                                        files={'file': BytesIO(open(file, 'rb').read())}).json()
         return response
 
+    def delete_friend(self, qq: int):
+        """删除好友
+        :param qq: 好友 QQ 号
+        """
+        content = {'sessionKey': self.session_key,
+                   'target': qq}
+        if self.adapter == 'http':
+            response = self.__session.post(url=f'{self.base_url}/deleteFriend', json=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='deleteFriend', content=content)
+            return response
+
     def mute(self, group: int, qq: int, time: int):
         """禁言群成员
         :param group: 指定群的群号
@@ -549,10 +597,41 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send(command='unmuteAll', content=content)
             return response
 
-    def file_list(self, dir_id: Optional[str] = None, group: Optional[int] = None,
+    def set_essence(self, msg_id: int):
+        """设置群精华消息
+        :param msg_id: 精华消息的 messageId
+        """
+        content = {'sessionKey': self.session_key,
+                   'target': msg_id}
+        if self.adapter == 'http':
+            response = self.__session.post(url=f'{self.base_url}/setEssence', json=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='setEssence', content=content)
+            return response
+
+    def member_admin(self, group: int, qq: int, assign: bool = True):
+        """修改群员的管理员权限
+        :param group: 指定群的群号
+        :param qq: 群员 QQ 号
+        :param assign: 是否设置为管理员
+        """
+        content = {'sessionKey': self.session_key,
+                   'target': group,
+                   'memberId': qq,
+                   'assign': assign}
+        if self.adapter == 'http':
+            response = self.__session.post(url=f'{self.base_url}/memberAdmin', json=content).json()
+            return response
+        elif self.adapter == 'ws':
+            response = self.__ws_send(command='memberAdmin', content=content)
+            return response
+
+    def file_list(self, dir_id: Optional[str] = None, path: Optional[str] = None, group: Optional[int] = None,
                   qq: Optional[int] = None, with_download_info: bool = False):
         """获取文件列表，目前仅支持群文件的操作
         :param dir_id: 文件夹 id，空为根目录
+        :param path: 文件夹路径，优先级高于 dir_id；文件夹允许重名，不保证准确，准确定位使用 dir_id
         :param group：群号，可选
         :param qq：好友 QQ 号，可选
         :param with_download_info：是否携带下载信息，额外请求，无必要不要携带
@@ -561,6 +640,8 @@ class Mirai(metaclass=Singleton):
         content = {'sessionKey': self.session_key,
                    'id': dir_id if dir_id else '',
                    'withDownloadInfo': with_download_info}
+        if path:
+            content['path'] = path
         if group:
             content['group'] = group
         if qq:
@@ -572,10 +653,11 @@ class Mirai(metaclass=Singleton):
             response = self.__ws_send('file_list', content=content)
             return response
 
-    def file_info(self, file: Union[File, str], group: Optional[int] = None,
+    def file_info(self, file: Union[File, str], path: Optional[str] = None, group: Optional[int] = None,
                   qq: Optional[int] = None, with_download_info: bool = False):
         """获取文件信息
-        :param file: 文件对象或文件唯一ID
+        :param file: 文件对象或文件唯一 ID
+        :param path: 文件夹路径，优先级高于 file；文件夹允许重名，不保证准确，准确定位使用 file
         :param group：群号，可选
         :param qq：好友 QQ 号，可选
         :param with_download_info：是否携带下载信息，额外请求，无必要不要携带
@@ -587,6 +669,8 @@ class Mirai(metaclass=Singleton):
             content['id'] = file.file_id
         else:
             content['id'] = file
+        if path:
+            content['path'] = path
         if group:
             content['group'] = group
         if qq:
@@ -604,7 +688,7 @@ class Mirai(metaclass=Singleton):
         :param group: 指定群的群号
         :return: 成员在指定群内是否为群主
         """
-        member_list = self.get_member_list(group)['data']
+        member_list = self.member_list(group)['data']
         if qq == self.qq:
             return member_list[0].get('group', {}).get('permission', None) == 'OWNER'
         for member in member_list:
@@ -623,7 +707,7 @@ class Mirai(metaclass=Singleton):
         :param group: 指定群的群号
         :return: 成员在指定群内是否为管理员
         """
-        member_list = self.get_member_list(group)['data']
+        member_list = self.member_list(group)['data']
         if qq == self.qq:
             return member_list[0].get('group', {}).get('permission', None) in ['OWNER', 'ADMINISTRATOR']
         for member in member_list:
